package net.jieyuu.service.impl;

import lombok.extern.slf4j.Slf4j;
import net.jieyuu.enums.BizCodeEnum;
import net.jieyuu.enums.SendCodeEnum;
import net.jieyuu.model.UserDO;
import net.jieyuu.mapper.UserMapper;
import net.jieyuu.request.UserRegisterRequest;
import net.jieyuu.service.NotifyService;
import net.jieyuu.service.UserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import net.jieyuu.utils.JsonData;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author jieyuu
 * @since 2024-02-12
 */
@Service
@Slf4j
public class UserServiceImpl extends ServiceImpl<UserMapper, UserDO> implements UserService {

    @Autowired
    NotifyService notifyService;

    @Autowired
    UserMapper userMapper;

    /**
     * 用户注册
     * 邮箱验证码验证
     * 密码加密 TODO
     * 账号唯一性检查 TODO
     * 插入数据库
     * 新注册用户福利发放 TODO
     *
     * @param userRegisterRequest
     * @return
     */
    @Override
    public JsonData register(UserRegisterRequest userRegisterRequest) {
        boolean checkCode = false;
        //校验验证码
        if (StringUtils.isNotBlank(userRegisterRequest.getMail())) {
            checkCode = notifyService.checkCode(SendCodeEnum.USER_REGISTER, userRegisterRequest.getMail(), userRegisterRequest.getCode());
        }

        if (!checkCode) {
            //验证码错误
            return JsonData.buildResult(BizCodeEnum.CODE_CAPTCHA);
        }

        UserDO userDO = new UserDO();
        BeanUtils.copyProperties(userRegisterRequest, userDO);

        //设置创建时间
        userDO.setCreateTime(new Date());
        //todo 思考老师的设置是否有问题
//        userDO.setSlogan("");
        //todo 设置密码 加密
//        userDO.setPwd(userRegisterRequest.getPwd());

        //账号唯一性检查 todo
        if (checkUnique(userDO.getMail())) {
            //插入数据库
            int rows = userMapper.insert(userDO);
            log.info("rows:{},注册成功{}", rows, userDO.toString());

            //新用户创建成功，初始化，发福利 todo
            userRegisterInitTask(userDO);
            return JsonData.buildSuccess();

        } else {
            return JsonData.buildResult(BizCodeEnum.ACCOUNT_REPEAT);
        }
    }


    /**
     * 校验用户账号唯一
     * @param mail
     * @return
     */
    private boolean checkUnique(String mail) {
        return false;

    }

    /**
     * 用户注册，初始化福利信息 todo
     * @param userDO
     */
    private void userRegisterInitTask(UserDO userDO) {

    }
}
